@@ -734,9 +734,7 @@ static void app_clone(GnomeMDI *mdi, GnomeApp *app)
 	}
 
 	app_create(mdi, layout_string);
-
-	if(layout_string)
-		g_free(layout_string);
+	g_free(layout_string);
 }
 
 static gint app_close_top (GnomeApp *app, GdkEventAny *event, GnomeMDI *mdi)
@@ -1556,7 +1554,7 @@ void gnome_mdi_open_toplevel (GnomeMDI *mdi)
  **/
 void gnome_mdi_update_child (GnomeMDI *mdi, GnomeMDIChild *child)
 {
-	GtkWidget *view, *title;
+	GtkWidget *view;
 	GList *view_node;
 
 	g_return_if_fail(mdi != NULL);
@@ -1581,14 +1579,6 @@ void gnome_mdi_update_child (GnomeMDI *mdi, GnomeMDIChild *child)
 								 fullname);
 			g_free(fullname);
 		}
-		else if(mdi->mode == GNOME_MDI_NOTEBOOK) {
-			GtkWidget *tab_label;
-
-			tab_label = gtk_notebook_get_tab_label
-				(GTK_NOTEBOOK (view->parent), view);
-			if(tab_label != NULL)
-				title = child_set_label(child, tab_label);
-		}
 
 		view_node = g_list_next(view_node);
 	}
@@ -1874,9 +1864,7 @@ void gnome_mdi_set_child_menu_path (GnomeMDI *mdi, const gchar *path)
 	g_return_if_fail(mdi != NULL);
 	g_return_if_fail(GNOME_IS_MDI(mdi));
 
-	if(mdi->child_menu_path)
-		g_free(mdi->child_menu_path);
-
+	g_free(mdi->child_menu_path);
 	mdi->child_menu_path = g_strdup(path);
 }
 
@@ -1898,9 +1886,7 @@ void gnome_mdi_set_child_list_path (GnomeMDI *mdi, const gchar *path)
 	g_return_if_fail(mdi != NULL);
 	g_return_if_fail(GNOME_IS_MDI(mdi));
 
-	if(mdi->child_list_path)
-		g_free(mdi->child_list_path);
-
+	g_free(mdi->child_list_path);
 	mdi->child_list_path = g_strdup(path);
 }
 
